# -*- coding: utf-8 -*-
"""
Automatic tests for module ldap0.functions
"""

from __future__ import absolute_import

# from Python's standard lib
import unittest

import ldap0
from ldap0.functions import attr_set
from ldap0.dn import escape_dn_chars
from ldap0.filter import escape_filter_chars


class TestFunction(unittest.TestCase):
    """
    test ldap0.functions
    """

    def test_ldap_strf_secs(self):
        """
        test function ldap_strf_secs()
        """
        self.assertEqual(ldap0.strf_secs(0), '19700101000000Z')
        self.assertEqual(ldap0.strf_secs(1466947067), '20160626131747Z')

    def test_ldap_strp_secs(self):
        """
        test function ldap_strp_secs()
        """
        self.assertEqual(ldap0.strp_secs('19700101000000Z'), 0)
        self.assertEqual(ldap0.strp_secs('20160626131747Z'), 1466947067)

    def test_escape_str(self):
        """
        test function escape_string_tmpl()
        """
        self.assertEqual(
            ldap0.escape_str(
                escape_filter_chars,
                '(&(objectClass=aeUser)(uid=%s))',
                'foo'
            ),
            '(&(objectClass=aeUser)(uid=foo))'
        )
        self.assertEqual(
            ldap0.escape_str(
                escape_filter_chars,
                '(&(objectClass=aeUser)(uid=%s))',
                'foo)bar'
            ),
            '(&(objectClass=aeUser)(uid=foo\\29bar))'
        )
        self.assertEqual(
            ldap0.escape_str(
                escape_dn_chars,
                'uid=%s',
                'foo=bar'
            ),
            'uid=foo\\=bar'
        )
        self.assertEqual(
            ldap0.escape_str(
                escape_dn_chars,
                'uid=%s,cn=%s,cn=%s,dc=example,dc=com',
                'foo=bar',
                'foo+',
                '+bar',
            ),
            'uid=foo\\=bar,cn=foo\\+,cn=\\+bar,dc=example,dc=com'
        )

    def test_attr_set(self):
        self.assertEqual(
            attr_set('foo bar foobar'),
            {'foobar', 'foo', 'bar'}
        )
        self.assertEqual(
            attr_set('foo,bar,foobar'),
            {'foobar', 'foo', 'bar'}
        )
        self.assertEqual(
            attr_set('    foo, bar, foobar'),
            {'foobar', 'foo', 'bar'}
        )
        self.assertEqual(
            attr_set('    foo, bar, foo bar'),
            {'foo', 'bar'}
        )


if __name__ == '__main__':
    unittest.main()
